==> dogtag-pki_11.0.3.orig.tar.xz: pki-11.0.3/base/console/src/main/java/com/netscape/admin/certsrv/config/install/WIRACertValidityPage.java <==
// --- BEGIN COPYRIGHT BLOCK ---
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// (C) 2007 Red Hat, Inc.
// All rights reserved.
// --- END COPYRIGHT BLOCK ---
package com.netscape.admin.certsrv.config.install;

import javax.swing.*;
import com.netscape.admin.certsrv.wizard.*;

/**
 * Validity page for RA signing certificate.
 *
 * @author Christine Ho
 * @version $Revision$, $Date$
 * @see com.netscape.admin.certsrv.config.install
 */
class WIRACertValidityPage extends WICertValidityPage {
    private static final String PANELNAME = "INSTALLRACERTVALIDWIZARD";
    private static final String RAHELPINDEX = "install-racert-validity-wizard-help";
    private static final String RAKRAHELPINDEX = "install-rakracert-validity-wizard-help";

    WIRACertValidityPage(JDialog parent) {
        super(PANELNAME);
        mParent = parent;
    }

    WIRACertValidityPage(JDialog parent, JFrame adminFrame) {
        super(PANELNAME);
        mParent = parent;
        mAdminFrame = adminFrame;
    }

    @Override
    public boolean initializePanel(WizardInfo info) {
        InstallWizardInfo wizardInfo = (InstallWizardInfo)info;
        if (wizardInfo.isCloning() && wizardInfo.isRACloningDone())
            return false;
        if (!wizardInfo.isRAInstalled() || wizardInfo.isRALocalCertDone() ||
          wizardInfo.isRACertRequestDone() || wizardInfo.isRACertInstalledDone())
            return false;
        if (super.initializePanel(info)) {
            if (!wizardInfo.isRACertLocalCA())
                return false;

            if (wizardInfo.isRAInstalled() && wizardInfo.isKRAInstalled())
                mHelpIndex = RAKRAHELPINDEX;
            else
                mHelpIndex = RAHELPINDEX;

            return true;
        }
        return false;
    }
}

==> dogtag-pki_11.2.1.orig.tar.xz: pki-11.2.1/base/console/src/main/java/com/netscape/admin/certsrv/config/install/WIRACertValidityPage.java <==
// --- BEGIN COPYRIGHT BLOCK ---
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// (C) 2007 Red Hat, Inc.
// All rights reserved.
// --- END COPYRIGHT BLOCK ---
package com.netscape.admin.certsrv.config.install;

import javax.swing.JDialog;
import javax.swing.JFrame;

import com.netscape.admin.certsrv.wizard.WizardInfo;

/**
 * Validity page for RA signing certificate.
 *
 * @author Christine Ho
 * @version $Revision$, $Date$
 * @see com.netscape.admin.certsrv.config.install
 * @deprecated The PKI console will be removed once there are CLI equivalents of desired console features.
 */
@Deprecated(since="10.14.0", forRemoval=true)
class WIRACertValidityPage extends WICertValidityPage {
    private static final String PANELNAME = "INSTALLRACERTVALIDWIZARD";
    private static final String RAHELPINDEX = "install-racert-validity-wizard-help";
    private static final String RAKRAHELPINDEX = "install-rakracert-validity-wizard-help";

    WIRACertValidityPage(JDialog parent) {
        super(PANELNAME);
        mParent = parent;
    }

    WIRACertValidityPage(JDialog parent, JFrame adminFrame) {
        super(PANELNAME);
        mParent = parent;
        mAdminFrame = adminFrame;
    }

    @Override
    public boolean initializePanel(WizardInfo info) {
        InstallWizardInfo wizardInfo = (InstallWizardInfo)info;
        if (wizardInfo.isCloning() && wizardInfo.isRACloningDone())
            return false;
        if (!wizardInfo.isRAInstalled() || wizardInfo.isRALocalCertDone() ||
          wizardInfo.isRACertRequestDone() || wizardInfo.isRACertInstalledDone())
            return false;
        if (super.initializePanel(info)) {
            if (!wizardInfo.isRACertLocalCA())
                return false;

            if (wizardInfo.isRAInstalled() && wizardInfo.isKRAInstalled())
                mHelpIndex = RAKRAHELPINDEX;
            else
                mHelpIndex = RAHELPINDEX;

            return true;
        }
        return false;
    }
}
